//Source file: LoadLevel.java
//Date: December 2006
//Framework Data Types for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw;

/**
 * Defines the Sequence of Data Elements that specify load level values. 
 *
 */
public final class LoadLevel implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static LoadLevel[] _array = new LoadLevel[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LoadLevel(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Normal load
     */
    public static final int _LOAD_LEVEL_NORMAL =  0;

    /**
     * Normal load
     */
    public static final LoadLevel LOAD_LEVEL_NORMAL = new LoadLevel(_LOAD_LEVEL_NORMAL);

    /**
     * Overload
     */
    public static final int _LOAD_LEVEL_OVERLOAD =  1;

    /**
     * Overload
     */
    public static final LoadLevel LOAD_LEVEL_OVERLOAD = new LoadLevel(_LOAD_LEVEL_OVERLOAD);

    /**
     * Severe Overload 
     */
    public static final int _LOAD_LEVEL_SEVERE_OVERLOAD =  2;

    /**
     * Severe Overload 
     */
    public static final LoadLevel LOAD_LEVEL_SEVERE_OVERLOAD = new LoadLevel(_LOAD_LEVEL_SEVERE_OVERLOAD);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LoadLevel object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LoadLevel object
     */
    public String getValueText() {
        switch (_value) {
            case _LOAD_LEVEL_NORMAL:
                return "LOAD_LEVEL_NORMAL";
            case _LOAD_LEVEL_OVERLOAD:
                return "LOAD_LEVEL_OVERLOAD";
            case _LOAD_LEVEL_SEVERE_OVERLOAD:
                return "LOAD_LEVEL_SEVERE_OVERLOAD";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LoadLevel getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LoadLevel)) {
            return false;
        }
        LoadLevel loadLevel = (LoadLevel) o; 
        if(!(this.getValue() == loadLevel.getValue())) {
            return false;
        }
        if (this.hashCode() != loadLevel.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LoadLevel

