//Source file: ServiceProfileDescription.java
//Date: December 2006
//Framework Data Types for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw;

/**
 * This data type is a Sequence of Data Elements which describes a Service Profile. A service contract contains one or more Service Profiles, one for each SAG in the enterprise operator domain. A service profile is a restriction of the service contract in order to provide restricted service features to a SAG. 
Note 1: 	When the Framework returns a TpServiceProfileDescription to the enterprise operator, it should set the ServiceTypeName field to the same value as the corresponding field of the service contract; When the enterprise operator passes a TpServiceProfileDescription to the Framework, the Framework should ignore the value sent in the ServiceTypeName field to ensure interoperability; The enterprise operator should be required to set the ServiceTypeName field to the correct value when passing a TpServiceProfileDescription to the Framework.
Note 2: 	The InUse flag indicates if the profile is currently in use by a service instance and will be returned in describeServiceProfile().  This flag will be ignored if it is passed in to createServiceProfile().
Note 3: 	The ServiceID field is used to restrict a service type-based service contract to a specific service.  When the TpServiceProfileDescription is passed to the Framework by an enterprise operator, the Framework should ensure that the ServiceID field, if not empty, contains a service which is of the service type specified in the service contract.  If the corresponding contract is for a service ID then the Framework should ignore this field.  
When a TpServiceProfileDescription is returned to the enterprise operator, the contents of this field will depend on the associated service contract.  If the contract is for a service ID, then this field should be populated with the correct value.  If the contract is for a service type, and the profile is restricted to a specific service ID then this field should be populated with the correct value.  Otherwise, it should contain an empty string.
 * 
 */
public final class ServiceProfileDescription implements java.io.Serializable {

    private String serviceContractID;
    private String serviceStartDate;
    private String serviceEndDate;
    private String serviceTypeName;
    private org.csapi.jr.se.fw.ServiceProperty[] serviceSubscriptionProperties;
    private boolean inUse;
    private String serviceID;

    /**
     * Creates a new ServiceProfileDescription instance.
     */
    public ServiceProfileDescription () {}

    /**
     * Creates a new ServiceProfileDescription instance.
     * @param _serviceContractID   
     * @param _serviceStartDate   
     * @param _serviceEndDate   
     * @param _serviceTypeName   
     * @param _serviceSubscriptionProperties   
     * @param _inUse   
     * @param _serviceID   
     */
    public ServiceProfileDescription (String _serviceContractID, String _serviceStartDate, String _serviceEndDate, String _serviceTypeName, org.csapi.jr.se.fw.ServiceProperty[] _serviceSubscriptionProperties, boolean _inUse, String _serviceID) {

        this.serviceContractID = _serviceContractID;
        this.serviceStartDate = _serviceStartDate;
        this.serviceEndDate = _serviceEndDate;
        this.serviceTypeName = _serviceTypeName;
        this.serviceSubscriptionProperties = _serviceSubscriptionProperties;
        this.inUse = _inUse;
        this.serviceID = _serviceID;
    }

    /**
     * This method returns a serviceContractID.
     * 
     * @return a String value
     */
    public String getServiceContractID() {
        return serviceContractID;
    }

    /**
     * This method returns a serviceStartDate.
     * 
     * @return a String value
     */
    public String getServiceStartDate() {
        return serviceStartDate;
    }

    /**
     * This method returns a serviceEndDate.
     * 
     * @return a String value
     */
    public String getServiceEndDate() {
        return serviceEndDate;
    }

    /**
     * This method returns a serviceTypeName.
     * 
     * @return a String value
     */
    public String getServiceTypeName() {
        return serviceTypeName;
    }

    /**
     * This method returns a serviceSubscriptionProperties.
     * 
     * @return a org.csapi.jr.se.fw.ServiceProperty[] value
     */
    public org.csapi.jr.se.fw.ServiceProperty[] getServiceSubscriptionProperties() {
        return serviceSubscriptionProperties;
    }

    /**
     * This method returns a inUse.
     * 
     * @return a boolean value
     */
    public boolean getInUse() {
        return inUse;
    }

    /**
     * This method returns a serviceID.
     * 
     * @return a String value
     */
    public String getServiceID() {
        return serviceID;
    }


    /**
     * This method sets a serviceContractID.
     */ 
    public void setServiceContractID(String serviceContractID) {
        this.serviceContractID = serviceContractID;
    }

    /**
     * This method sets a serviceStartDate.
     */ 
    public void setServiceStartDate(String serviceStartDate) {
        this.serviceStartDate = serviceStartDate;
    }

    /**
     * This method sets a serviceEndDate.
     */ 
    public void setServiceEndDate(String serviceEndDate) {
        this.serviceEndDate = serviceEndDate;
    }

    /**
     * This method sets a serviceTypeName.
     */ 
    public void setServiceTypeName(String serviceTypeName) {
        this.serviceTypeName = serviceTypeName;
    }

    /**
     * This method sets a serviceSubscriptionProperties.
     */ 
    public void setServiceSubscriptionProperties(org.csapi.jr.se.fw.ServiceProperty[] serviceSubscriptionProperties) {
        this.serviceSubscriptionProperties = serviceSubscriptionProperties;
    }

    /**
     * This method sets a inUse.
     */ 
    public void setInUse(boolean inUse) {
        this.inUse = inUse;
    }

    /**
     * This method sets a serviceID.
     */ 
    public void setServiceID(String serviceID) {
        this.serviceID = serviceID;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ServiceProfileDescription)) {
            return false;
        } 
        ServiceProfileDescription serviceProfileDescription = (ServiceProfileDescription) o;
        if(!(this.serviceContractID == serviceProfileDescription.serviceContractID))  {
            return false;
        }
        if(!(this.serviceStartDate == serviceProfileDescription.serviceStartDate))  {
            return false;
        }
        if(!(this.serviceEndDate == serviceProfileDescription.serviceEndDate))  {
            return false;
        }
        if(!(this.serviceSubscriptionProperties == serviceProfileDescription.serviceSubscriptionProperties))  {
            return false;
        }
        if(!(this.serviceTypeName == serviceProfileDescription.serviceTypeName))  {
            return false;
        }
        if(!(this.inUse == serviceProfileDescription.inUse)) {
            return false;
        }
        if(!(this.serviceID == serviceProfileDescription.serviceID))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ServiceProfileDescription

