//Source file: ClientAppInfoQuery.java
//Date: December 2006
//Framework to Enterprise Operator Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * This interface is used by the enterprise operator to list the client applications and the SAGs in its domain and to obtain information about them.
 *
 */
public interface ClientAppInfoQuery extends org.csapi.jr.se.CsapiInterface{

    /**
     * Query information about the specified client application of the enterprise operator.
     * @return clientAppDescription    The "clientAppDescription" parameter contains the clientApp description.
     * @param clientAppID The "clientAppID" parameter identifies the clientApp object whose description is requested.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     */
    org.csapi.jr.se.fw.ClientAppDescription  describeClientApp(String clientAppID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException;

    /**
     * Get a list of all client applications belonging to an enterprise operator.
     * @return clientAppIDs    The "clientAppIDs" parameter identifies the list of client applications in the enterprise operator domain.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     */
    String[]  listClientApps() throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException;

    /**
     * Query information about the specified SAG associated with the enterprise operator.
     * @return SagDescription    The "sagDescription" parameter returns the SAG-specific description.
     * @param sagID The "sagID" parameter identifies the SAG whose description is required.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidSagIdException     Invalid Subscription Assignment Group ID
     */
    String  describeSAG(String sagID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Get a list of all SAGs associated with an enterprise operator.
     * @return SagIDList    The "sagIDList" parameter returns the list of the identifiers of the SAGs associated with the enterprise operator.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     */
    String[]  listSAGs() throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException;

    /**
     * Get a list of all client applications associated with the specified SAG.
     * @return clientAppIDList    The "clientAppIDList" parameter returns the list of the client applications associated with the SAG.
     * @param sagID The "sagID" parameter identifies the SAG whose clientAppID list is required.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidSagIdException     Invalid Subscription Assignment Group ID
     */
    String[]  listSAGMembers(String sagID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Obtain a list of the SAGs of which the specified client application is a member. 
     * @return sags    The SAGs of which the client application is a member.
     * @param clientAppID The "clientAppID" parameter identifies the clientApp object whose membership details are requested.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     */
    String[]  listClientAppMembership(String clientAppID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException;


} // ClientAppInfoQuery

