//Source file: ClientAppManagement.java
//Date: December 2006
//Framework to Enterprise Operator Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * If the enterprise operator wants the client applications in its domain to access the subscribed services in name of the enterprise, then (s)he has to register these client applications in the Framework domain. For this the enterprise operator must use the client application management interface, to which (s)he can subscribe as a privileged user. The client application management interface is intended for cases where an organisation wants to allow several client applications to register with a Framework as service consumers. It allows enterprise operators to dynamically add new client applications and SAGs, delete them and to modify subscription related information concerning the client applications and the SAGs. Client applications use the subscribed services in the enterprise operator's name. The main task of client application management is to register, modify and delete client applications (Client Application Management), and manage groups of client applications, called Subscription Assignment Groups (SAG Management).
 *
 */
public interface ClientAppManagement extends org.csapi.jr.se.CsapiInterface{

    /**
     * A client application is represented in the Framework domain as a  "clientApp object". This method creates a new clientApp object associated with the enterprise operator object. Each clientApp object has a clientApp ID and other subscription related client application's properties stored in it.
     * @param clientAppDescription The "clientAppDescription" parameter contains the clientApp ID that is to be associated with the newly created clientApp object and the subscription-related  "client application properties".  The clientApp ID must be a unique ID across framework, if the ID already exists, an exception "P_INVALID_CLIENT_APP_ID" would be raised. The client application properties are a list of name/value pairs. The client application properties are an item for bi-lateral agreement between the enterprise operator and the framework operator.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     */
    void  createClientApp(org.csapi.jr.se.fw.ClientAppDescription clientAppDescription) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException;

    /**
     * Modify the information contained in an existing clientApp object associated with the enterprise operator.  An exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     * @param clientAppDescription The "clientAppDescription" parameter contains the modified client application information. If the clientApp ID does not exist, an exception "P_INVALID_CLIENT_APP_ID" would be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     */
    void  modifyClientApp(org.csapi.jr.se.fw.ClientAppDescription clientAppDescription) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException;

    /**
     * Delete the specified client application associated with the enterprise operator.  If the client application currently has an access session with the framework then this will be terminated, along with any service instances it may have created.  An exception of "P_TASK_REFUSED" will be raised if a non-associated enterprise operator invokes this method. 
     * @param clientAppID The "clientAppID" parameter identifies the client application that is to be deleted. If the clientAppID does not exist, a "P_INVALID_CLIENT_APP_ID" exception will be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     */
    void  deleteClientApp(String clientAppID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException;

    /**
     * Create a  new SAG associated with the enterprise operator. The SAG object is identified by a SAG - ID and contains SAG - specific description.
     * @param sag The "sag" parameter contains the SAG-ID and SAG-specific description. This sagID is particular to the SAG, and must be unique across framework.  If the sagID supplied already exists, an exception of type "P_INVALID_SAG_ID" would be raised.
     * @param clientAppIDs The "clientAppIDs" parameter contains the list of client application IDs that are to be associated with the newly created SAG.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     * @exception org.csapi.jr.se.fw.InvalidSagIdException     Invalid Subscription Assignment Group ID
     */
    void  createSAG(org.csapi.jr.se.fw.Sag sag, String[] clientAppIDs) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException, org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Modify the description of an existing SAG associated with the enterprise operator.  An exception of "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     * @param sag The "sag" parameter contains the modified SAG-specific description. If the SAG ID does not exist, an exception "P_INVALID_SAG_ID" would be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidSagIdException     Invalid Subscription Assignment Group ID
     */
    void  modifySAG(org.csapi.jr.se.fw.Sag sag) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Delete an existing SAG.  Only the enterprise operator associated with the SAG is allowed to delete it, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     * @param sagID The "sagID" parameter identifies the SAG that is to be deleted.  If the SAG ID does not exist, an exception "P_INVALID_SAG_ID" is raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidSagIdException     Invalid Subscription Assignment Group ID
     */
    void  deleteSAG(String sagID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Add the specified client applications to the specified SAG associated with the enterprise operator.  Only the enterprise operator associated with the SAG is allowed to assign members to it, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.  Each client application may be assigned to a service only through a single service profile at a particular moment in time. If this condition is violated, a "P_INVALID_ADDITION_TO_SAG" would be raised. In this case, no partial execution of this method is performed. The enterprise operator can query further information about this invalid addition using the method requestConflictInfo().
     * @param sagID The "sagID" parameter identifies the SAG object to which the client applications are to be added.  If the SAG ID does not exist, an exception "P_INVALID_SAG_ID" would be raised.
     * @param clientAppIDs The "clientAppIDs" parameter contains the list of the clientApp IDs that are to be added to the specified SAG. The clientApp objects are first created using the createClientApp() method.  If one or all of the client application IDs in the list does not exist, an exception "P_INVALID_CLIENT_APP_ID" would be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     * @exception org.csapi.jr.se.fw.InvalidSagIdException     Invalid Subscription Assignment Group ID
     * @exception org.csapi.jr.se.fw.InvalidAdditionToSagException     A client application cannot be added to the SAG because this would imply that the client application has two concurrent service profiles at a particular moment in time for a particular service.
     */
    void  addSAGMembers(String sagID, String[] clientAppIDs) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException, org.csapi.jr.se.fw.InvalidSagIdException, org.csapi.jr.se.fw.InvalidAdditionToSagException;

    /**
     * Delete specified client applications from the specified SAG object of the enterprise operator.  Only the enterprise operator associated with the SAG is allowed to remove members from it, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     * @param sagID The "sagID" parameter identifies the SAG from which the client applications are to be removed.  If the SAG ID does not exist, an exception "P_INVALID_SAG_ID" would be raised.
     * @param clientAppIDList The "clientAppIDList" parameter contains the list of the clientApp IDs that are to be removed from the specified SAG.  If one or all of the client application IDs in the list does not exist, an exception "P_INVALID_CLIENT_APP_ID" would be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidClientAppIdException     Invalid Client Application ID
     * @exception org.csapi.jr.se.fw.InvalidSagIdException     Invalid Subscription Assignment Group ID
     */
    void  removeSAGMembers(String sagID, String[] clientAppIDList) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidClientAppIdException, org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Requests details about the latest conflict that occurred during performing the method addSagMembers() on this interface (that is Information about the invocation of addSagMembers() that raised a P_INVALID_ADDITION_TO_SAG). Each client application may be assigned to a service only through a single service profile at a particular moment in time. The enterprise operator might try to add a client application to a SAG, where both, the client application and the SAG are already assigned to the same service through different service profiles. As this may happen in one method call for multiple client applications, a conflict list is generated. 
It is only possible to retrieve information about the last conflicting addSagMembers() method call; information about previous conflicts cannot be requested. If there has never been a conflict, the method returns an empty conflict list.
     * @return TpAddSagMembersConflictList    The list of conflicts of the last invocation of addSagMembers() that raised a P_INVALID_ADDITION_TO_SAG. Each conflict contains the following elements 
	a. the conflict generating client application.																					b. the SAG and the service profile through which the conflict generating client application is already assigned to the conflict generating service. It includes the current service profile.																c. the SAG, to which the conflict generating client application should be added. However, this SAG is already assigned to a concurrent service profile concerning the conflict generating service. This creates a conflict, as each client application may be assigned to a service only through a single service profile at a particular moment in time.				d. the conflict generating service. 
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     */
    org.csapi.jr.se.fw.AddSagMembersConflict[]  requestConflictInfo() throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException;


} // ClientAppManagement

