//Source file: EntOpAccountManagement.java
//Date: December 2006
//Framework to Enterprise Operator Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * The enterprise operator, in the role of the service subscriber, uses this interface for the management of enterprise operator subscription accounts, such as modify and delete enterprise operator accounts.  The EntOpID will be decided in an off-line agreement between the FW operator and the EntOp, as the EntOp may require the ID to be something more meaningful than a random number.  The EntOp account, consisting of the EntOpID, along with the list of valid properties and their modes and prescribed ranges, will be entered via a FW operator interface that is currently outside the scope of the API.
 *
 */
public interface EntOpAccountManagement extends org.csapi.jr.se.CsapiInterface{

    /**
     * Modification of the enterprise operator information contained in the enterprise operator object. 
     * @param enterpriseOperatorProperties The "enterprise operator properties" parameter conveys the modified/populated information about the enterprise operator. The values of the "enterprise operator properties" can only be modified within the prescribed range, as negotiated earlier (an off-line process) between the enterprise operator and the framework operator, otherwise a P_INVALID_PROPERTY exception is raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidPropertyException     The framework does not recognise the property supplied by the client
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  modifyEntOpAccount(org.csapi.jr.se.fw.Property[] enterpriseOperatorProperties) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidPropertyException, org.csapi.jr.se.PlatformException;

    /**
     * Deletes the specified enterprise operator object. Deletion of the enterprise operator object cannot be performed until the enterprise operator has deleted all the service contracts (and the Service Profiles) associated with it. An attempt to delete the enterprise operator account will result in a P_TASK_REFUSED exception if there are outstanding service contracts (and service profiles).
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  deleteEntOpAccount() throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.PlatformException;


} // EntOpAccountManagement

