//Source file: ServiceContractInfoQuery.java
//Date: December 2006
//Framework to Enterprise Operator Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * The enterprise operator uses this interface to query information about a given service contract.
 *
 */
public interface ServiceContractInfoQuery extends org.csapi.jr.se.CsapiInterface{

    /**
     * Query information about the specified service contract. The enterprise operator invokes this operation to obtain information that is stored in the specified service contract. The enterprise operator can only obtain information about the service contracts that it has created.
     * @return serviceContractDescription    The "serviceContract" parameter contains the description for the specified service contract. 
     * @param serviceContractID The "serviceContractID" parameter identifies the service whose description is being requested. 
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidServiceContractIdException     Invalid Service Contract ID
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    org.csapi.jr.se.fw.ServiceContractDescription  describeServiceContract(String serviceContractID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidServiceContractIdException, org.csapi.jr.se.PlatformException;

    /**
     *      * @return  a list of the IDs of service contracts created by the Enterprise Operator. 
     * @return serviceContractIDs    The "serviceContractIDs" parameter will contain a list of IDs for service contracts that the enterprise operator has created.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    String[]  listServiceContracts() throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.PlatformException;

    /**
     * The enterprise operator invokes this operation to obtain a list of service profiles that are associated with a particular service contract. 
     * @return serviceProfileIDs    This contains the service profiles associated with a particular service contract. 
     * @param serviceContractID The "serviceContractID" parameter identifies the service contract.  If the serviceContractID is not recognised by the framework, an exception "P_INVALID_SERVICE_CONTRACT_ID" would be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidServiceContractIdException     Invalid Service Contract ID
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    String[]  listServiceProfiles(String serviceContractID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidServiceContractIdException, org.csapi.jr.se.PlatformException;


} // ServiceContractInfoQuery

