//Source file: ServiceContractManagement.java
//Date: December 2006
//Framework to Enterprise Operator Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * The enterprise operator uses this interface for service contract management, such as create, modify, and delete service contracts.
 *
 */
public interface ServiceContractManagement extends org.csapi.jr.se.CsapiInterface{

    /**
     * Create a new service contract for an enterprise operator. The enterprise operator provides the service contract description. This contract should conform to the previously negotiated high - level agreement (regarding the services, their usage and the price, etc.), if any, between the enterprise operator and the framework operator, otherwise the appropriate exception is raised by the framework.  When the description has been validated, a service contract ID will be generated.
     * @return serviceContractID    The service contract ID will be used to uniquely identify the service contract within the framework.
     * @param serviceContractDescription The "serviceContractDescription" parameter provides the information contained in the service contract. The service contract is a structured data type, which contains the following information 																	a. information about the service requestor, that is, the enterprise operator;														b. information about the billing contact (person);																				c. service start date;																												d. service end date;																												e. service type (for example obtained from listServiceType() method);																f. service ID (for example obtained from discoverService() method).  For certain services, service type information is sufficient and service ID may not be required.  This implies that any service of the type specified above is subscribed and hence accessible to the enterprise operator or to its client applications;														g. list of service subscription properties and their value ranges (service profiles further restrict these value ranges).
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    String  createServiceContract(org.csapi.jr.se.fw.ServiceContractDescription serviceContractDescription) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.PlatformException;

    /**
     * Modify an existing service contract. The service contract can be modified only within the context of a pre-existing off-line negotiated high-level agreement between the enterprise operator and the framework operator.  Only the enterprise operator associated with the serviceContract is allowed to modify it, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     * @param serviceContract The "serviceContract" parameter provides the modified service contract.  If the serviceContractID does not exist, an exception "P_INVALID_SERVICE_CONTRACT_ID" would be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidServiceIdException     Invalid service ID
     * @exception org.csapi.jr.se.fw.InvalidServiceContractIdException     Invalid Service Contract ID
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  modifyServiceContract(org.csapi.jr.se.fw.ServiceContract serviceContract) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidServiceIdException, org.csapi.jr.se.fw.InvalidServiceContractIdException, org.csapi.jr.se.PlatformException;

    /**
     * Delete an existing service contract. All the Service Profiles associated with the service contract are also deleted.  If there are any service instances running that are governed by this contract, or any of the profiles associated with it, then they will be terminated.  Only the enterprise operator associated with the serviceContract is allowed to delete it, a "P_TASK_REFUSED" exception will be raised if a non-associated enterprise operator invokes this method. 
     * @param serviceContractID The "serviceContractID" parameter identifies the service contract that the enterprise operator wishes to delete.  If the serviceContractID does not exist, a "P_INVALID_SERVICE_CONTRACT_ID" exception will be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidServiceContractIdException     Invalid Service Contract ID
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  deleteServiceContract(String serviceContractID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidServiceContractIdException, org.csapi.jr.se.PlatformException;


} // ServiceContractManagement

