//Source file: ServiceProfileInfoQuery.java
//Date: December 2006
//Framework to Enterprise Operator Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * This interface is used by the enterprise operator to obtain information about individual Service Profiles, to find out which SAGs are assigned to a given Service Profile, and to find out what Service Profile is associated with a given client application or SAG.
 *
 */
public interface ServiceProfileInfoQuery extends org.csapi.jr.se.CsapiInterface{

    /**
     * Get a list of all service profiles created by the enterprise operator.
     * @return serviceProfileIDList    The "serviceProfileIDList" is a list of the service profiles associated with the enterprise operator.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    String[]  listServiceProfiles() throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.PlatformException;

    /**
     * Query information about a single service profile.
     * @return serviceProfileDescription    The "serviceProfileDescription" parameter is a structured data type which contains a description for the specified service profile.
     * @param serviceProfileID The "serviceProfileID" parameter identifies the Service Profile whose description is being requested.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidServiceProfileIdException     Invalid service profile ID
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    org.csapi.jr.se.fw.ServiceProfileDescription  describeServiceProfile(String serviceProfileID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidServiceProfileIdException, org.csapi.jr.se.PlatformException;

    /**
     * Get a list of SAGs assigned to the specified service profile. 
     * @return sagIDList    The "sagIDs" parameter is the list of the SAG IDs that are assigned to the specified service profile.
     * @param serviceProfileID The "serviceProfileID" parameter identifies the Service Profile.  If the serviceProfileID is not recognised by the framework, an exception "P_INVALID_SERVICE_PROFILE_ID" would be raised.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.AccessDeniedException     The client is not currently authenticated with the framework
     * @exception org.csapi.jr.se.fw.InvalidServiceProfileIdException     Invalid service profile ID
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    String[]  listAssignedMembers(String serviceProfileID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.AccessDeniedException, org.csapi.jr.se.fw.InvalidServiceProfileIdException, org.csapi.jr.se.PlatformException;


} // ServiceProfileInfoQuery

