//Source file: FwFaultManager.java
//Date: December 2006
//Framework to Service Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_service.integrity;

/**
 * This interface is used by the service instance to inform the framework of events which affect the integrity of the API, and request fault management status information from the framework.  The fault manager operations do not exchange callback interfaces as it is assumed that the service instance has supplied its Fault Management callback interface at the time it obtains the Framework's Fault Management interface, by use of the obtainInterfaceWithCallback operation on the IpAccess interface.																												If the IpFwFaultManager interface is implemented by a Framework, at least one of these methods shall be implemented.  If the Framework is capable of invoking the IpSvcFaultManager.svcActivityTestReq() method, it shall implement svcActivityTestRes() and svcActivityTestErr() in this interface.  If the Framework is capable of invoking IpSvcFaultManager.generateFaultStatisticsRecordReq(), it shall implement generateFaultStatisticsRecordRes() and generateFaultStatisticsRecordErr() in this interface.  If the Framework is capable of invoking IpSvcFaultManager.generateFaultStatisticsRecordReq(), it shall implement generateFaultStatisticsRecordRes() and generateFaultStatisticsRecordErr() in this interface. 
 *
 */
public interface FwFaultManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The service instance invokes this method to test that the framework or the client application is operational. On receipt of this request, the framework must carry out a test on itself or on the application, to check that it is operating correctly. The framework reports the test result by invoking the activityTestRes method on the IpSvcFaultManager interface.
     * @param activityTestID The identifier provided by the service instance to correlate the response (when it arrives) with this request.
     * @param testSubject Identifies the subject for testing (framework or client application).
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  activityTestReq(int activityTestID, org.csapi.jr.se.fw.SubjectType testSubject) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to return the result of a framework-requested activity test.
     * @param activityTestID Used by the framework to correlate this response (when it arrives) with the original request.
     * @param activityTestResult The result of the activity test.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidActivityTestIdException     ID does not correspond to a valid activity test request
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  svcActivityTestRes(int activityTestID, String activityTestResult) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidActivityTestIdException, org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the service instance to inform the framework that the client application is not responding.  On receipt of this indication, the framework must act to inform the client application.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  appUnavailableInd() throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * The service instance uses this method to indicate that an error occurred during a framework-requested activity test. 
     * @param activityTestID Used by the framework to correlate this response (when it arrives) with the original request.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidActivityTestIdException     ID does not correspond to a valid activity test request
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  svcActivityTestErr(int activityTestID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidActivityTestIdException, org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the service instance to inform the framework that it is about to become unavailable for use according to the provided reason and as well to inform the Framework when the Service instance becomes available again. The framework should inform the client applications that are currently using this service instance that it is unavailable and as well when it becomes available again for use (via the svcAvailStatusInd method on the IpAppFaultManager interface).
     * @param reason Identifies the reason for the service instance's unavailability and also the reason SERVICE_AVAILABLE to be used to inform the Framework when the Service instance becomes available again.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  svcAvailStatusInd(org.csapi.jr.se.fw.SvcAvailStatusReason reason) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the service instance to solicit fault statistics from the framework. On receipt of this request, the framework must produce a fault statistics record, for the framework or for the application during the specified time interval, which is returned to the service instance using the generateFaultStatisticsRecordRes operation on the IpSvcFaultManager interface. 
     * @param faultStatsReqID The identifier provided by the service instance to correlate the response (when it arrives) with this request.
     * @param timePeriod The period over which the fault statistics are to be generated. Supplying both a start time and stop time as empty strings leaves the time period to the discretion of the framework.
     * @param recordSubject Specifies the subject to be included in the general fault statistics record (framework or application).
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  generateFaultStatisticsRecordReq(int faultStatsReqID, org.csapi.jr.se.TimeInterval timePeriod, org.csapi.jr.se.fw.SubjectType recordSubject) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the service to provide fault statistics to the framework in response to a generateFaultStatisticsRecordReq method invocation on the IpSvcFaultManager interface.
     * @param faultStatsReqID Used by the framework to correlate this response (when it arrives) with the original request.
     * @param faultStatistics The fault statistics record.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  generateFaultStatisticsRecordRes(int faultStatsReqID, org.csapi.jr.se.fw.FaultStatsRecord faultStatistics) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the service to indicate an error fulfilling the request to provide fault statistics, in response to a generateFaultStatisticsRecordReq method invocation on the IpSvcFaultManager interface.
     * @param faultStatsReqID Used by the framework to correlate this error (when it arrives) with the original request.
     * @param faultStatisticsError The fault statistics error.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.PlatformException     The implementation detected an internal (for example, communication) error
     */
    void  generateFaultStatisticsRecordErr(int faultStatsReqID, org.csapi.jr.se.fw.FaultStatisticsError faultStatisticsError) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.PlatformException;


} // FwFaultManager

