//Source file: SvcFaultManager.java
//Date: December 2006
//Framework to Service Interfaces for 2nd draft ES 204 915-03 V1.1.1, DES/TISPAN-01032-03-OSA, Parlay 6.0

package org.csapi.jr.se.fw.fw_service.integrity;

/**
 * This interface is used to inform the service instance of events that affect the integrity of the Framework, Service or Client Application.  The Framework will invoke methods on the Fault Management Service Interface that is specified when the service instance obtains the Fault Management Framework interface  that is by use of the obtainInterfaceWithCallback operation on the IpAccess interface. 																If the IpSvcFaultManager interface is implemented by a Service, at least one of these methods shall be implemented.  If the Service is capable of invoking the IpFwFaultManager.activityTestReq() method, it shall implement activityTestRes() and activityTestErr() in this interface.  If the Service is capable of invoking IpFwFaultManager.generateFaultStatisticsRecordReq(), it shall implement generateFaultStatisticsRecordRes() and generateFaultStatisticsRecordErr() in this interface.
 *
 */
public interface SvcFaultManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The framework uses this method to return the result of a service-requested activity test.
     * @param activityTestID Used by the service to correlate this response (when it arrives) with the original request.
     * @param activityTestResult The result of the activity test.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidActivityTestIdException     ID does not correspond to a valid activity test request
     */
    void  activityTestRes(int activityTestID, String activityTestResult) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidActivityTestIdException;

    /**
     * The framework invokes this method to test that the service instance is operational. On receipt of this request, the service instance must carry out a test on itself, to check that it is operating correctly.  The service instance reports the test result by invoking the svcActivityTestRes method on the IpFwFaultManager interface.
     * @param activityTestID The identifier provided by the framework to correlate the response (when it arrives) with this request.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  svcActivityTestReq(int activityTestID) throws org.csapi.jr.se.CommonException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method fwAvailStatusInd shall be used instead, using the new type of reason parameter to inform the Service the reason why the Framework is unavailable.
The framework invokes this method to notify the service instance of a failure within the framework. The service instance must not continue to use the framework until it has recovered (as indicated by a fwFaultRecoveryInd).
     * @param fault Specifies the fault that has been detected by the framework.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @deprecated
     */
    void  fwFaultReportInd(org.csapi.jr.se.fw.InterfaceFault fault) throws org.csapi.jr.se.CommonException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method fwAvailStatusInd shall be used instead, using the new type of reason parameter to inform the Service when the Framework becomes available again.
The framework invokes this method to notify the service instance that a previously reported fault has been rectified.  The service instance may then resume using the framework.
     * @param fault Specifies the fault from which the framework has recovered.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @deprecated
     */
    void  fwFaultRecoveryInd(org.csapi.jr.se.fw.InterfaceFault fault) throws org.csapi.jr.se.CommonException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method fwAvailStatusInd shall be used instead, using the new type of reason parameter to inform the Application the reason why the Framework is unavailable and also when the Framework becomes available again.
The framework invokes this method to inform the service instance that it is no longer available.
     * @param reason Identifies the reason why the framework is no longer available.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @deprecated
     */
    void  fwUnavailableInd(org.csapi.jr.se.fw.FwUnavailReason reason) throws org.csapi.jr.se.CommonException;

    /**
     * The framework invokes this method to inform the service instance that the client application has reported that it can no longer use the service instance.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  svcUnavailableInd() throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to indicate that an error occurred during a service-requested activity test. 
     * @param activityTestID Used by the service instance to correlate this response (when it arrives) with the original request.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.fw.InvalidActivityTestIdException     ID does not correspond to a valid activity test request
     */
    void  activityTestErr(int activityTestID) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.fw.InvalidActivityTestIdException;

    /**
     * The framework invokes this method to inform the service instance that the client application is no longer available using different reasons for the unavailability. This may be a result of the application reporting a failure.  Alternatively, the framework may have detected that the application has failed  for example non-response from an activity test, failure to return heartbeats, using the reason APP_UNAVAILABLE_NO_RESPONSE. When the application becomes available again the reason APP_AVAILABLE shall be used to inform the Service about that.
     * @param reason Identifies the reason why the application is no longer available. APP_AVAILABLE is used to inform the Service that the Application is available again. 
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  appAvailStatusInd(org.csapi.jr.se.fw.AppAvailStatusReason reason) throws org.csapi.jr.se.CommonException;

    /**
     * This method is used by the framework to provide fault statistics to a service instance in response to a generateFaultStatisticsRecordReq method invocation on the IpFwFaultManager interface. 
     * @param faultStatsReqID Used by the service instance to correlate this response (when it arrives) with the original request.
     * @param faultStatistics The fault statistics record.
     * @param recordSubject Specifies the entity (framework or application)  whose fault statistics record has been provided.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  generateFaultStatisticsRecordRes(int faultStatsReqID, org.csapi.jr.se.fw.FaultStatsRecord faultStatistics, org.csapi.jr.se.fw.SubjectType recordSubject) throws org.csapi.jr.se.CommonException;

    /**
     * This method is used by the framework to indicate an error fulfilling the request to provide fault statistics, in response to a generateFaultStatisticsRecordReq method invocation on the IpFwFaultManager interface.
     * @param faultStatsReqID Used by the service instance to correlate this error (when it arrives) with the original request.
     * @param faultStatisticsError The fault statistics error.
     * @param recordSubject Specifies the entity (framework or application) whose fault statistics record was requested.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  generateFaultStatisticsRecordErr(int faultStatsReqID, org.csapi.jr.se.fw.FaultStatisticsError faultStatisticsError, org.csapi.jr.se.fw.SubjectType recordSubject) throws org.csapi.jr.se.CommonException;

    /**
     * This method is used by the framework to solicit fault statistics from the service instance, for example when the framework was asked for these statistics by the client application using the generateFaultStatisticsRecordReq operation on the IpFaultManager interface. On receipt of this request the service instance must produce a fault statistics record during the specified time interval, which is returned to the framework using the generateFaultStatisticsRecordRes operation on the IpFwFaultManager interface.
     * @param faultStatsReqID The identifier provided by the framework to correlate the response (when it arrives) with this request.
     * @param timePeriod The period over which the fault statistics are to be generated. Supplying both a start time and stop time as empty strings leaves the time period to the discretion of the service.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  generateFaultStatisticsRecordReq(int faultStatsReqID, org.csapi.jr.se.TimeInterval timePeriod) throws org.csapi.jr.se.CommonException;

    /**
     * The framework invokes this method to inform the service instance about the Framework availability status, that is that it can no longer use the Framework according to the reason parameter or that the Framework has become available again. The service instance may wait for the problem to be solved and just stop the usage of the Framework until the fwAvailStatusInd() is called again with the reason FRAMEWORK_AVAILABLE.  
     * @param reason Identifies the reason why the framework is no longer available or that it has become available again.
     */
    void  fwAvailStatusInd(org.csapi.jr.se.fw.FwAvailStatusReason reason);


} // SvcFaultManager

